package Qt::XmlPatterns::QAbstractMessageHandler;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QAbstractMessageHandler
# file     : QtXmlPatterns/qabstractmessagehandler.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::XmlPatterns::QAbstractMessageHandler

=head1 PUBLIC METHODS

=over

=item   QAbstractMessageHandler(QObject * parent)

=item   QAbstractMessageHandler(QObject * parent = 0)

=item   ~QAbstractMessageHandler()

=item  void message(QtMsgType type, const QString & description, const QUrl & identifier, const QSourceLocation & sourceLocation)

=item  void message(QtMsgType type, const QString & description, const QUrl & identifier, const QSourceLocation & sourceLocation = QSourceLocation())

=item  void message(QtMsgType type, const QString & description, const QUrl & identifier = QUrl(), const QSourceLocation & sourceLocation = QSourceLocation())


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
